@@ -13,7 +13,4 @@ yourself (or hire someone to make it) and use it. There is no maintenance
 required.
 """
 
-import comments
-import feed
-
-VERSION = '1.2.2'
+VERSION = '1.4.0'
