@@ -1,6 +1,6 @@
 # -*- encoding: utf-8 -*-
 
-from django.core.cache import get_cache
+from django.core.cache import caches
 
 from .models import Template
 
@@ -12,24 +12,18 @@ def get_template():
 
     @return (string, int)
     """
-
     try:
-
-        cache = get_cache('default')
+        cache = caches['default']
 
         if not cache.get('template'):
-
             template = Template.objects.get(active=True)
-
             current_template = (template.template, template.submenu_max_characters)
             cache.set('template', current_template, 30)
 
         else:
-
             current_template = cache.get('template')
 
     except Template.DoesNotExist:
-
         current_template = ('default', 150)
 
     return current_template
