@@ -7,12 +7,11 @@ from ..language.models import Language
 
 
 class Menu(models.Model):
-    '''
+    """
     Stores data about menu.
     There may be reason to have multiple menu
     Links in the header for example
-    '''
-
+    """
     name = models.CharField(
         _('Menu name'),
         help_text=_('For identification only'),
@@ -23,18 +22,18 @@ class Menu(models.Model):
         return self.name
 
     class Meta:
+        app_label = 'django_pages'
         verbose_name = _('Menu')
         verbose_name_plural = _('Menu')
 
 
 class MenuItem(models.Model):
-    '''
+    """
     Stores menuitem information.
     It is recommended to write urls in SEO format,
     e.g.: this_is_my_site_describing_something.
     Is related to :model: `django_pages.Menu`.
-    '''
-
+    """
     lang = models.ForeignKey(Language, verbose_name=_('Language'))
     menu = models.ForeignKey(Menu, verbose_name=_('Menu'))
     menuitem_name = models.CharField(_('Menu item name'), max_length=200)
@@ -78,7 +77,6 @@ class MenuItem(models.Model):
         """
         repositions items after deletion or exception
         """
-
         items = MenuItem.objects.filter(
             lang=self.lang,
             menu=self.menu
@@ -193,5 +191,6 @@ class MenuItem(models.Model):
             return '/{}/{}'.format(self.lang.country_code, self.url)
 
     class Meta:
+        app_label = 'django_pages'
         verbose_name = _('Menu item')
         verbose_name_plural = _('Menu items')
