@@ -1,20 +1,31 @@
-﻿
-/**
- * @license Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.html or http://ckeditor.com/license
+﻿/**
+ * @license Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+ * For licensing, see LICENSE.md or http://ckeditor.com/license
  */
 
 /**
  * This file was added automatically by CKEditor builder.
- * You may re-use it at any time at http://ckeditor.com/builder to build CKEditor again.
- * 
- * NOTE: 
+ * You may re-use it at any time to build CKEditor again.
+ *
+ * If you would like to build CKEditor online again
+ * (for example to upgrade), visit one the following links:
+ *
+ * (1) http://ckeditor.com/builder
+ *     Visit online builder to build CKEditor from scratch.
+ *
+ * (2) http://ckeditor.com/builder/87e583d6b895631dbc4038ca1988de9a
+ *     Visit online builder to build CKEditor, starting with the same setup as before.
+ *
+ * (3) http://ckeditor.com/builder/download/87e583d6b895631dbc4038ca1988de9a
+ *     Straight download link to the latest version of CKEditor (Optimized) with the same setup as before.
+ *
+ * NOTE:
  *    This file is not used by CKEditor, you may remove it.
  *    Changing this file will not change your CKEditor configuration.
  */
 
 var CKBUILDER_CONFIG = {
-	skin: 'moono',
+	skin: 'moonocolor',
 	preset: 'full',
 	ignore: [
 		'dev',
@@ -24,20 +35,16 @@ var CKBUILDER_CONFIG = {
 		'.mailmap'
 	],
 	plugins : {
-		'about' : 1,
 		'a11yhelp' : 1,
-		'dialogadvtab' : 1,
 		'basicstyles' : 1,
 		'bidi' : 1,
 		'blockquote' : 1,
 		'clipboard' : 1,
 		'colorbutton' : 1,
 		'colordialog' : 1,
-		'templates' : 1,
 		'contextmenu' : 1,
+		'dialogadvtab' : 1,
 		'div' : 1,
-		'resize' : 1,
-		'toolbar' : 1,
 		'elementspath' : 1,
 		'enterkey' : 1,
 		'entities' : 1,
@@ -46,16 +53,16 @@ var CKBUILDER_CONFIG = {
 		'flash' : 1,
 		'floatingspace' : 1,
 		'font' : 1,
-		'forms' : 1,
 		'format' : 1,
-		'htmlwriter' : 1,
+		'forms' : 1,
 		'horizontalrule' : 1,
+		'htmlwriter' : 1,
 		'iframe' : 1,
-		'wysiwygarea' : 1,
 		'image' : 1,
-		'indent' : 1,
-		'smiley' : 1,
+		'indentblock' : 1,
+		'indentlist' : 1,
 		'justify' : 1,
+		'language' : 1,
 		'link' : 1,
 		'list' : 1,
 		'liststyle' : 1,
@@ -63,41 +70,32 @@ var CKBUILDER_CONFIG = {
 		'maximize' : 1,
 		'newpage' : 1,
 		'pagebreak' : 1,
-		'pastetext' : 1,
 		'pastefromword' : 1,
+		'pastetext' : 1,
 		'preview' : 1,
 		'print' : 1,
 		'removeformat' : 1,
+		'resize' : 1,
 		'save' : 1,
+		'scayt' : 1,
 		'selectall' : 1,
 		'showblocks' : 1,
 		'showborders' : 1,
+		'smiley' : 1,
 		'sourcearea' : 1,
 		'specialchar' : 1,
-		'scayt' : 1,
 		'stylescombo' : 1,
 		'tab' : 1,
 		'table' : 1,
 		'tabletools' : 1,
+		'templates' : 1,
+		'toolbar' : 1,
 		'undo' : 1,
 		'wsc' : 1,
-		'dialog' : 1,
-		'dialogui' : 1,
-		'panelbutton' : 1,
-		'button' : 1,
-		'floatpanel' : 1,
-		'panel' : 1,
-		'menu' : 1,
-		'popup' : 1,
-		'fakeobjects' : 1,
-		'richcombo' : 1,
-		'listblock' : 1,
-		'menubutton' : 1,
-		'autogrow' : 1,
-		'indentlist' : 1
+		'wysiwygarea' : 1
 	},
 	languages : {
 		'cs' : 1,
-		'en' : 1,
+		'en' : 1
 	}
-};
\ No newline at end of file
+};
